@@ -122,6 +122,7 @@ RecordingBrightness=0
 PreviousProfile="silent"
 PreviousVolume=50
 
+gstream_player=""
 
 language="" #2-letter country code
 
@@ -200,3 +201,5 @@ cliStop=""
 
 CurrentVolume=5 #start value for wake up music
 WakeUp_Song_Volume_Increase_Step=4 #increase step time in pro mille (0.1%)
+
+SongIsPlaying=False
