@@ -24,20 +24,24 @@ import os, os.path
 import dbus
 from dbus.mainloop.qt import DBusQtMainLoop
 
+#import shlex, subprocess
+
+#import pygst
+#pygst.require("0.10")
+##import gobject
+##gobject.threads_init()
+#import gst
+
 import data
 import filter_data #filter
 import records #record data
 
-
-
 import i18n #load language file
 _ = i18n.language.ugettext
 
 
 
 
-
-
 ###########################################################################
 ## Function:    LoadConfig
 ## Description: This function loads the preset names from the preset names file
@@ -589,6 +593,7 @@ def getFileList(path,  filter):
     #Note: Above command could also be implemented with os.listdir(). This might give a minor speed improvement
     arr=output.split("\n")
     arr.pop()
+    print len(arr), "files ("+filter+") in", path
     return arr
 
 
@@ -602,11 +607,24 @@ def getFileList(path,  filter):
 ## Returns:     none
 ###########################################################################
 def PlaySong(volume, filename):
+    data.SongIsPlaying=True
     print strftime("%x %X"), "Play", filename, "with volume", volume
     cmd="dbus-send --print-reply --dest=com.nokia.mediaplayer /com/nokia/mediaplayer com.nokia.mediaplayer.mime_open string:\"file:///"+str(filename)+"\""
+#    cmd="mplayer \""+str(filename)+"\""
     SetVolume(volume)
     b = os.popen(cmd)
     b.close()
+#    proc = subprocess.Popen(cmd, shell=True)
+
+#    data.gstream_player = gst.element_factory_make("playbin2", "player")
+#    fakesink = gst.element_factory_make("fakesink", "fakesink")
+#    data.gstream_player.set_property("video-sink", fakesink)
+#
+#    data.gstream_player.set_property("uri", "file://" + filename)
+#    data.gstream_player.set_state(gst.STATE_PLAYING)
+
+
+
 
 
 
@@ -618,16 +636,35 @@ def PlaySong(volume, filename):
 ## Parameters:  none
 ## Returns:     volume percent: 0..100
 ###########################################################################
-def PauseSong():
-    print strftime("%x %X"), "Pause song (if active)"
-    cmd="dbus-send --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.renderer.pause"
-    b = os.popen(cmd)
-    b.close()
+#def PauseSong():
+#    print strftime("%x %X"), "Pause song (if active)"
+#    cmd="dbus-send --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.renderer.pause"
+#    b = os.popen(cmd)
+#    b.close()
 
 
 
 
 
+###########################################################################
+## Function:    StopMediaPlayer
+## Description: This function closes the media player
+## Parameters:  none
+## Returns:     none
+###########################################################################
+def StopMediaPlayer():
+    if(data.SongIsPlaying==True):
+        data.SongIsPlaying=False
+        print strftime("%x %X"), "Stop mediaplayer"
+        cmd="killall mediaplayer"
+#        cmd="killall mplayer"
+        b = os.popen(cmd)
+        b.close()
+#        data.gstream_player.set_state(gst.STATE_NULL)
+
+
+
+
 ###########################################################################
 ## Function:    GetSongLength
 ## Description: This function returns the duration of a song
@@ -652,25 +689,8 @@ def GetSongLength(filename):
 
 
 
-
 ###########################################################################
-## Function:    CloseMediaPlayer
-## Description: This function closes the media player
-## Parameters:  none
-## Returns:     none
-###########################################################################
-def CloseMediaPlayer():
-    print strftime("%x %X"), "killall mediaplayer"
-    cmd="killall mediaplayer"
-    b = os.popen(cmd)
-    b.close()
-
-
-
-
-
-###########################################################################
-## Function:    CloseMediaPlayer
+## Function:    StopMediaPlayer
 ## Description: This function can measure the time needed for a certain code block
 ##                It is only used for debugging
 ## Parameters:  text to be printer, reset time: True/False
