@@ -27,6 +27,13 @@ from functions_record import *
 def install_excepthook(app_name,app_version):
 
     def my_excepthook(exctype, value, tb):
+
+        #stop media player and alarm
+        StopMediaPlayer()
+        delete_all_Alarms()
+
+
+
         #traceback give us all the errors information message like the method, file line ... everything like
         #we have in the python interpreter
         s = ''.join(traceback.format_exception(exctype, value, tb))
